@@ -39,18 +39,17 @@ def Kronecker(system, u_, vs, lambda_=None, linf_constant = None):
     rabinowitsch_system = [rabinowitsch_R(f) for f in system] + [rabinowitsch_R(linf)]
     if lambda_:
         if (MPolynomialIdeal(rabinowitsch_R, rabinowitsch_system + [lambda_*(1-lambda_*x0)]).dimension() > 0):
-            print(f"{bcolors.WARNING}Warning:{bcolors.ENDC} H has a point with vanishing partial derivatives.")
-            print(f"{bcolors.WARNING}Warning:{bcolors.ENDC} Any minimal critical point computations performed may be incorrect.")
+            print(f"{bcolors.WARNING}Warning:{bcolors.ENDC} A critical point exists with λ = 0.")
+            print(f"{bcolors.WARNING}Warning:{bcolors.ENDC} Any minimal critical point computations performed may be incomplete.")
         rabinowitsch_system += [1-lambda_*x0]
     n = len(rabinowitsch_R.gens())
-    #print("Rabinowitsch System", rabinowitsch_system)
 
     # Compute Grobner basis for ordered system of polynomials
     I = MPolynomialIdeal(rabinowitsch_R, rabinowitsch_system)
     try:
         I = MPolynomialIdeal(rabinowitsch_R, I.groebner_basis())
     except:
-        raise Exception("Trouble computing Groebner basis. System may be too large.")
+        raise ACSVException("Trouble computing Groebner basis. System may be too large.")
     
     big_gb = I.transformed_basis('fglm')
 
@@ -66,7 +65,7 @@ def Kronecker(system, u_, vs, lambda_=None, linf_constant = None):
         print(rabinowitsch_system)
         print(Ps)
         print(gb)
-        raise Exception("No P polynomial found for Kronecker Representation.")
+        raise ACSVException("No P polynomial found for Kronecker Representation.")
     u_ = Ps[0].variables()[0]
     R = PolynomialRing(QQ, u_)
     P = R(Ps[0])
@@ -80,14 +79,14 @@ def Kronecker(system, u_, vs, lambda_=None, linf_constant = None):
         eqns = [f for f in gb if z in f.variables()]
         if len(eqns) != 1:
             print(eqns, z, vs)
-            raise Exception("Linear form does not separate the roots.")
+            raise ACSVException("Linear form does not separate the roots.")
             return
 
         eq = eqns[0].polynomial(z)
 
         if eq.degree() != 1:
             print(eq, z)
-            raise Exception("Linear form does not separate the roots.")
+            raise ACSVException("Linear form does not separate the roots.")
             return
         _, rem = (Pd*eq.roots()[0][0]).quo_rem(P)
         Qs.append(rem)
@@ -139,14 +138,11 @@ def NumericalKronecker(P, Qs, show_time=False):
             roots = P.polynomial(u_).roots(ComplexIntervalField(root_precision), multiplicities=False)
         else:
             break
-        timer.checkpoint("Smale Iteration")
     else:
         print(f"{bcolors.WARNING}Warning: {bcolors.ENDC} Could not find roots close enough to pass Smale's alpha test. Root approximations may be inaccurate.")
     
     timer.checkpoint("Final Smale Iteration")
 
-    # `PrecisionbyQ`` computes the annihilating polynomials for each variable v
-    # and returns the amount of precision needed to separate different values of v
     precisionByQ = []
     for Q in Qs:
         # Precision for Q depends on degree and height of annihilating polynomial
@@ -156,8 +152,6 @@ def NumericalKronecker(P, Qs, show_time=False):
         h = GetHeight(P) * PdQDegree + PdQHeight * P.degree() + log(factorial(P.degree() + PdQDegree)) + PdQDegree + P.degree()
         precisionByQ.append(deg**((deg+2)/2)*(h * sqrt(P.degree()))**(deg-1) + 5)
 
-    timer.checkpoint("Get Precision By Q")
-
     # Number of binary digits needed in approximation of Q_j/P'
     digits = int(SafeLog(max(precisionByQ+[precision]))) + 1
 
@@ -175,7 +169,7 @@ def NumericalKronecker(P, Qs, show_time=False):
     kappa = SafeInt(RIF(SafeLog(max(Pd_max, Q_max))).upper()) + digits
     kappa = SafeInt(kappa)
 
-    timer.checkpoint("Get Precision")
+    timer.checkpoint()
 
     precise_roots = roots
 
@@ -340,7 +334,7 @@ def MinimalCriticalCombinatorial(G, H, variables, r = None, linf_constant = None
             elif precision_t_step >= precision_t:
                 # We already found t to enough precision to determine the range
                 # Yet the two checks above still failed
-                raise Exception("Could not determine range of t:" +  str(t_val))
+                raise ACSVException("Could not determine range of t:" +  str(t_val))
                 break
             else:
                 # Increase precision of t and try again
@@ -361,7 +355,7 @@ def MinimalCriticalCombinatorial(G, H, variables, r = None, linf_constant = None
     if len(minimals) == 0:
         raise ACSVException(f"No smooth minimal critical points found.")
     elif len(minimals) > 1:
-        raise Exception(f"More than one minimal point with positive real coordinates found.")
+        raise ACSVException(f"More than one minimal point with positive real coordinates found.")
         print("Error: More than one minimal point with positive real coordinates found.")
 
     # Change the equations to only deal with t=1 solutions
